import unittest

__all__ = ["test"]


def test() -> unittest.TextTestRunner:
    "This function runs all the tests."
    loader: unittest.TestLoader
    suite: unittest.TestSuite
    runner: unittest.TextTestRunner
    result: unittest.TextTestResult
    loader = unittest.TestLoader()
    suite = loader.discover(start_dir="kwargshold.tests")
    runner = unittest.TextTestRunner()
    result = runner.run(suite)
    return result



import unittest
from typing import *


class Test1984(unittest.TestCase):
    def test_1984(self: Self) -> None:
        self.assertEqual(2 + 2, 4, "Ignorance is Strength")


if __name__ == "__main__":
    unittest.main()
